# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from zitadel_client.models.action_service_beta_create_target_response import ActionServiceBetaCreateTargetResponse
from zitadel_client.models.action_service_beta_delete_target_response import ActionServiceBetaDeleteTargetResponse
from zitadel_client.models.action_service_beta_get_target_response import ActionServiceBetaGetTargetResponse
from zitadel_client.models.action_service_beta_list_execution_functions_response import ActionServiceBetaListExecutionFunctionsResponse
from zitadel_client.models.action_service_beta_list_execution_methods_response import ActionServiceBetaListExecutionMethodsResponse
from zitadel_client.models.action_service_beta_list_execution_services_response import ActionServiceBetaListExecutionServicesResponse
from zitadel_client.models.action_service_beta_list_executions_response import ActionServiceBetaListExecutionsResponse
from zitadel_client.models.action_service_beta_list_targets_response import ActionServiceBetaListTargetsResponse
from zitadel_client.models.action_service_beta_set_execution_response import ActionServiceBetaSetExecutionResponse
from zitadel_client.models.action_service_beta_update_target_response import ActionServiceBetaUpdateTargetResponse
from zitadel_client.models.action_service_create_target_request import ActionServiceCreateTargetRequest
from zitadel_client.models.action_service_list_targets_request import ActionServiceListTargetsRequest
from zitadel_client.models.action_service_set_execution_request import ActionServiceSetExecutionRequest
from zitadel_client.models.action_service_update_target_request import ActionServiceUpdateTargetRequest

from zitadel_client.api_client import ApiClient, RequestSerialized
from zitadel_client.api_response import ApiResponse
from zitadel_client.rest import RESTResponseType


class ActionServiceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def action_service_create_target(
        self,
        action_service_create_target_request: ActionServiceCreateTargetRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaCreateTargetResponse:
        """Create Target

        Create a new target to your endpoint, which can be used in executions.  Required permission:   - `action.target.write`  Required feature flag:   - `actions`

        :param action_service_create_target_request: (required)
        :type action_service_create_target_request: ActionServiceCreateTargetRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_create_target_serialize(
            action_service_create_target_request=action_service_create_target_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaCreateTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
            '409': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_create_target_with_http_info(
        self,
        action_service_create_target_request: ActionServiceCreateTargetRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaCreateTargetResponse]:
        """Create Target

        Create a new target to your endpoint, which can be used in executions.  Required permission:   - `action.target.write`  Required feature flag:   - `actions`

        :param action_service_create_target_request: (required)
        :type action_service_create_target_request: ActionServiceCreateTargetRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_create_target_serialize(
            action_service_create_target_request=action_service_create_target_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaCreateTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
            '409': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_create_target_without_preload_content(
        self,
        action_service_create_target_request: ActionServiceCreateTargetRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Target

        Create a new target to your endpoint, which can be used in executions.  Required permission:   - `action.target.write`  Required feature flag:   - `actions`

        :param action_service_create_target_request: (required)
        :type action_service_create_target_request: ActionServiceCreateTargetRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_create_target_serialize(
            action_service_create_target_request=action_service_create_target_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaCreateTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
            '409': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_create_target_serialize(
        self,
        action_service_create_target_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if action_service_create_target_request is not None:
            _body_params = action_service_create_target_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2beta/actions/targets',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_delete_target(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaDeleteTargetResponse:
        """Delete Target

        Delete an existing target. This will remove it from any configured execution as well. In case the target is not found, the request will return a successful response as the desired state is already achieved.  Required permission:   - `action.target.delete`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_delete_target_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaDeleteTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_delete_target_with_http_info(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaDeleteTargetResponse]:
        """Delete Target

        Delete an existing target. This will remove it from any configured execution as well. In case the target is not found, the request will return a successful response as the desired state is already achieved.  Required permission:   - `action.target.delete`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_delete_target_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaDeleteTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_delete_target_without_preload_content(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Target

        Delete an existing target. This will remove it from any configured execution as well. In case the target is not found, the request will return a successful response as the desired state is already achieved.  Required permission:   - `action.target.delete`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_delete_target_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaDeleteTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_delete_target_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v2beta/actions/targets/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_get_target(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaGetTargetResponse:
        """Get Target

        Returns the target identified by the requested ID.  Required permission:   - `action.target.read`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_get_target_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaGetTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_get_target_with_http_info(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaGetTargetResponse]:
        """Get Target

        Returns the target identified by the requested ID.  Required permission:   - `action.target.read`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_get_target_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaGetTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_get_target_without_preload_content(
        self,
        id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Target

        Returns the target identified by the requested ID.  Required permission:   - `action.target.read`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_get_target_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaGetTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_get_target_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2beta/actions/targets/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_list_execution_functions(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaListExecutionFunctionsResponse:
        """List Execution Functions

        List all available functions which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_functions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionFunctionsResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_list_execution_functions_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaListExecutionFunctionsResponse]:
        """List Execution Functions

        List all available functions which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_functions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionFunctionsResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_list_execution_functions_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Execution Functions

        List all available functions which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_functions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionFunctionsResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_list_execution_functions_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2beta/actions/executions/functions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_list_execution_methods(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaListExecutionMethodsResponse:
        """List Execution Methods

        List all available methods which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_methods_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionMethodsResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_list_execution_methods_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaListExecutionMethodsResponse]:
        """List Execution Methods

        List all available methods which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_methods_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionMethodsResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_list_execution_methods_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Execution Methods

        List all available methods which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_methods_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionMethodsResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_list_execution_methods_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2beta/actions/executions/methods',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_list_execution_services(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaListExecutionServicesResponse:
        """List Execution Services

        List all available services which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_services_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionServicesResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_list_execution_services_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaListExecutionServicesResponse]:
        """List Execution Services

        List all available services which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_services_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionServicesResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_list_execution_services_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Execution Services

        List all available services which can be used as condition for executions.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_execution_services_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionServicesResponse",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_list_execution_services_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2beta/actions/executions/services',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_list_executions(
        self,
        pagination_offset: Annotated[Optional[StrictStr], Field(description="Starting point for retrieval, in combination of offset used to query a set list of objects.")] = None,
        pagination_limit: Annotated[Optional[StrictInt], Field(description="limit is the maximum amount of objects returned. The default is set to 100 with a maximum of 1000 in the runtime configuration. If the limit exceeds the maximum configured ZITADEL will throw an error. If no limit is present the default is taken.")] = None,
        pagination_asc: Annotated[Optional[StrictBool], Field(description="Asc is the sorting order. If true the list is sorted ascending, if false the list is sorted descending. The default is descending.")] = None,
        sorting_column: Annotated[Optional[StrictStr], Field(description="The field the result is sorted by. The default is the creation date. Beware that if you change this, your result pagination might be inconsistent.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaListExecutionsResponse:
        """List Executions

        List all matching executions. By default all executions of the instance are returned that have at least one execution target. Make sure to include a limit and sorting for pagination.  Required permission:   - `action.execution.read`  Required feature flag:   - `actions`

        :param pagination_offset: Starting point for retrieval, in combination of offset used to query a set list of objects.
        :type pagination_offset: str
        :param pagination_limit: limit is the maximum amount of objects returned. The default is set to 100 with a maximum of 1000 in the runtime configuration. If the limit exceeds the maximum configured ZITADEL will throw an error. If no limit is present the default is taken.
        :type pagination_limit: int
        :param pagination_asc: Asc is the sorting order. If true the list is sorted ascending, if false the list is sorted descending. The default is descending.
        :type pagination_asc: bool
        :param sorting_column: The field the result is sorted by. The default is the creation date. Beware that if you change this, your result pagination might be inconsistent.
        :type sorting_column: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_executions_serialize(
            pagination_offset=pagination_offset,
            pagination_limit=pagination_limit,
            pagination_asc=pagination_asc,
            sorting_column=sorting_column,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionsResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_list_executions_with_http_info(
        self,
        pagination_offset: Annotated[Optional[StrictStr], Field(description="Starting point for retrieval, in combination of offset used to query a set list of objects.")] = None,
        pagination_limit: Annotated[Optional[StrictInt], Field(description="limit is the maximum amount of objects returned. The default is set to 100 with a maximum of 1000 in the runtime configuration. If the limit exceeds the maximum configured ZITADEL will throw an error. If no limit is present the default is taken.")] = None,
        pagination_asc: Annotated[Optional[StrictBool], Field(description="Asc is the sorting order. If true the list is sorted ascending, if false the list is sorted descending. The default is descending.")] = None,
        sorting_column: Annotated[Optional[StrictStr], Field(description="The field the result is sorted by. The default is the creation date. Beware that if you change this, your result pagination might be inconsistent.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaListExecutionsResponse]:
        """List Executions

        List all matching executions. By default all executions of the instance are returned that have at least one execution target. Make sure to include a limit and sorting for pagination.  Required permission:   - `action.execution.read`  Required feature flag:   - `actions`

        :param pagination_offset: Starting point for retrieval, in combination of offset used to query a set list of objects.
        :type pagination_offset: str
        :param pagination_limit: limit is the maximum amount of objects returned. The default is set to 100 with a maximum of 1000 in the runtime configuration. If the limit exceeds the maximum configured ZITADEL will throw an error. If no limit is present the default is taken.
        :type pagination_limit: int
        :param pagination_asc: Asc is the sorting order. If true the list is sorted ascending, if false the list is sorted descending. The default is descending.
        :type pagination_asc: bool
        :param sorting_column: The field the result is sorted by. The default is the creation date. Beware that if you change this, your result pagination might be inconsistent.
        :type sorting_column: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_executions_serialize(
            pagination_offset=pagination_offset,
            pagination_limit=pagination_limit,
            pagination_asc=pagination_asc,
            sorting_column=sorting_column,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionsResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_list_executions_without_preload_content(
        self,
        pagination_offset: Annotated[Optional[StrictStr], Field(description="Starting point for retrieval, in combination of offset used to query a set list of objects.")] = None,
        pagination_limit: Annotated[Optional[StrictInt], Field(description="limit is the maximum amount of objects returned. The default is set to 100 with a maximum of 1000 in the runtime configuration. If the limit exceeds the maximum configured ZITADEL will throw an error. If no limit is present the default is taken.")] = None,
        pagination_asc: Annotated[Optional[StrictBool], Field(description="Asc is the sorting order. If true the list is sorted ascending, if false the list is sorted descending. The default is descending.")] = None,
        sorting_column: Annotated[Optional[StrictStr], Field(description="The field the result is sorted by. The default is the creation date. Beware that if you change this, your result pagination might be inconsistent.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Executions

        List all matching executions. By default all executions of the instance are returned that have at least one execution target. Make sure to include a limit and sorting for pagination.  Required permission:   - `action.execution.read`  Required feature flag:   - `actions`

        :param pagination_offset: Starting point for retrieval, in combination of offset used to query a set list of objects.
        :type pagination_offset: str
        :param pagination_limit: limit is the maximum amount of objects returned. The default is set to 100 with a maximum of 1000 in the runtime configuration. If the limit exceeds the maximum configured ZITADEL will throw an error. If no limit is present the default is taken.
        :type pagination_limit: int
        :param pagination_asc: Asc is the sorting order. If true the list is sorted ascending, if false the list is sorted descending. The default is descending.
        :type pagination_asc: bool
        :param sorting_column: The field the result is sorted by. The default is the creation date. Beware that if you change this, your result pagination might be inconsistent.
        :type sorting_column: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_executions_serialize(
            pagination_offset=pagination_offset,
            pagination_limit=pagination_limit,
            pagination_asc=pagination_asc,
            sorting_column=sorting_column,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListExecutionsResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_list_executions_serialize(
        self,
        pagination_offset,
        pagination_limit,
        pagination_asc,
        sorting_column,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if pagination_offset is not None:
            
            _query_params.append(('pagination.offset', pagination_offset))
            
        if pagination_limit is not None:
            
            _query_params.append(('pagination.limit', pagination_limit))
            
        if pagination_asc is not None:
            
            _query_params.append(('pagination.asc', pagination_asc))
            
        if sorting_column is not None:
            
            _query_params.append(('sortingColumn', sorting_column))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2beta/actions/executions/_search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_list_targets(
        self,
        action_service_list_targets_request: ActionServiceListTargetsRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaListTargetsResponse:
        """List targets

        List all matching targets. By default all targets of the instance are returned. Make sure to include a limit and sorting for pagination.  Required permission:   - `action.target.read`  Required feature flag:   - `actions`

        :param action_service_list_targets_request: (required)
        :type action_service_list_targets_request: ActionServiceListTargetsRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_targets_serialize(
            action_service_list_targets_request=action_service_list_targets_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListTargetsResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_list_targets_with_http_info(
        self,
        action_service_list_targets_request: ActionServiceListTargetsRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaListTargetsResponse]:
        """List targets

        List all matching targets. By default all targets of the instance are returned. Make sure to include a limit and sorting for pagination.  Required permission:   - `action.target.read`  Required feature flag:   - `actions`

        :param action_service_list_targets_request: (required)
        :type action_service_list_targets_request: ActionServiceListTargetsRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_targets_serialize(
            action_service_list_targets_request=action_service_list_targets_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListTargetsResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_list_targets_without_preload_content(
        self,
        action_service_list_targets_request: ActionServiceListTargetsRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List targets

        List all matching targets. By default all targets of the instance are returned. Make sure to include a limit and sorting for pagination.  Required permission:   - `action.target.read`  Required feature flag:   - `actions`

        :param action_service_list_targets_request: (required)
        :type action_service_list_targets_request: ActionServiceListTargetsRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_list_targets_serialize(
            action_service_list_targets_request=action_service_list_targets_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaListTargetsResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_list_targets_serialize(
        self,
        action_service_list_targets_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if action_service_list_targets_request is not None:
            _body_params = action_service_list_targets_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2beta/actions/targets/_search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_set_execution(
        self,
        action_service_set_execution_request: ActionServiceSetExecutionRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaSetExecutionResponse:
        """Set Execution

        Sets an execution to call a target or include the targets of another execution. Setting an empty list of targets will remove all targets from the execution, making it a noop.  Required permission:   - `action.execution.write`  Required feature flag:   - `actions`

        :param action_service_set_execution_request: (required)
        :type action_service_set_execution_request: ActionServiceSetExecutionRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_set_execution_serialize(
            action_service_set_execution_request=action_service_set_execution_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaSetExecutionResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_set_execution_with_http_info(
        self,
        action_service_set_execution_request: ActionServiceSetExecutionRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaSetExecutionResponse]:
        """Set Execution

        Sets an execution to call a target or include the targets of another execution. Setting an empty list of targets will remove all targets from the execution, making it a noop.  Required permission:   - `action.execution.write`  Required feature flag:   - `actions`

        :param action_service_set_execution_request: (required)
        :type action_service_set_execution_request: ActionServiceSetExecutionRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_set_execution_serialize(
            action_service_set_execution_request=action_service_set_execution_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaSetExecutionResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_set_execution_without_preload_content(
        self,
        action_service_set_execution_request: ActionServiceSetExecutionRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Set Execution

        Sets an execution to call a target or include the targets of another execution. Setting an empty list of targets will remove all targets from the execution, making it a noop.  Required permission:   - `action.execution.write`  Required feature flag:   - `actions`

        :param action_service_set_execution_request: (required)
        :type action_service_set_execution_request: ActionServiceSetExecutionRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_set_execution_serialize(
            action_service_set_execution_request=action_service_set_execution_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaSetExecutionResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "ActionServiceRpcStatus",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_set_execution_serialize(
        self,
        action_service_set_execution_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if action_service_set_execution_request is not None:
            _body_params = action_service_set_execution_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/v2beta/actions/executions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def action_service_update_target(
        self,
        id: StrictStr,
        action_service_update_target_request: ActionServiceUpdateTargetRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ActionServiceBetaUpdateTargetResponse:
        """Update Target

        Update an existing target. To generate a new signing key set the optional expirationSigningKey.  Required permission:   - `action.target.write`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param action_service_update_target_request: (required)
        :type action_service_update_target_request: ActionServiceUpdateTargetRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_update_target_serialize(
            id=id,
            action_service_update_target_request=action_service_update_target_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaUpdateTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def action_service_update_target_with_http_info(
        self,
        id: StrictStr,
        action_service_update_target_request: ActionServiceUpdateTargetRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ActionServiceBetaUpdateTargetResponse]:
        """Update Target

        Update an existing target. To generate a new signing key set the optional expirationSigningKey.  Required permission:   - `action.target.write`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param action_service_update_target_request: (required)
        :type action_service_update_target_request: ActionServiceUpdateTargetRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_update_target_serialize(
            id=id,
            action_service_update_target_request=action_service_update_target_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaUpdateTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def action_service_update_target_without_preload_content(
        self,
        id: StrictStr,
        action_service_update_target_request: ActionServiceUpdateTargetRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Target

        Update an existing target. To generate a new signing key set the optional expirationSigningKey.  Required permission:   - `action.target.write`  Required feature flag:   - `actions`

        :param id: (required)
        :type id: str
        :param action_service_update_target_request: (required)
        :type action_service_update_target_request: ActionServiceUpdateTargetRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._action_service_update_target_serialize(
            id=id,
            action_service_update_target_request=action_service_update_target_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ActionServiceBetaUpdateTargetResponse",
            '400': "object",
            '403': "ActionServiceRpcStatus",
            '404': "object",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _action_service_update_target_serialize(
        self,
        id,
        action_service_update_target_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if action_service_update_target_request is not None:
            _body_params = action_service_update_target_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'zitadelAccessToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2beta/actions/targets/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from zitadel_client.models.user_service_human_email import UserServiceHumanEmail
from zitadel_client.models.user_service_human_phone import UserServiceHumanPhone
from zitadel_client.models.user_service_human_profile import UserServiceHumanProfile
from zitadel_client.models.user_service_user_state import UserServiceUserState
from typing import Optional, Set
from typing_extensions import Self

class UserServiceHumanUser(BaseModel):
    """
    UserServiceHumanUser
    """ # noqa: E501
    user_id: Optional[StrictStr] = Field(default=None, description="Unique identifier of the user.", alias="userId")
    state: Optional[UserServiceUserState] = UserServiceUserState.USER_STATE_UNSPECIFIED
    username: Optional[StrictStr] = Field(default=None, description="Username of the user, which can be globally unique or unique on organization level.")
    login_names: Optional[List[StrictStr]] = Field(default=None, description="Possible usable login names for the user.", alias="loginNames")
    preferred_login_name: Optional[StrictStr] = Field(default=None, description="Preferred login name of the user.", alias="preferredLoginName")
    profile: Optional[UserServiceHumanProfile] = None
    email: Optional[UserServiceHumanEmail] = None
    phone: Optional[UserServiceHumanPhone] = None
    password_change_required: Optional[StrictBool] = Field(default=None, description="User is required to change the used password on the next login.", alias="passwordChangeRequired")
    password_changed: Optional[datetime] = Field(default=None, description="The time the user last changed their password.", alias="passwordChanged")
    mfa_init_skipped: Optional[datetime] = Field(default=None, description="The time the user last skipped MFA initialization.", alias="mfaInitSkipped")

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserServiceHumanUser from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of profile
        if self.profile:
            _dict['profile'] = self.profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of email
        if self.email:
            _dict['email'] = self.email.to_dict()
        # override the default output from pydantic by calling `to_dict()` of phone
        if self.phone:
            _dict['phone'] = self.phone.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserServiceHumanUser from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "userId": obj.get("userId"),
            "state": obj.get("state") if obj.get("state") is not None else UserServiceUserState.USER_STATE_UNSPECIFIED,
            "username": obj.get("username"),
            "loginNames": obj.get("loginNames"),
            "preferredLoginName": obj.get("preferredLoginName"),
            "profile": UserServiceHumanProfile.from_dict(obj["profile"]) if obj.get("profile") is not None else None,
            "email": UserServiceHumanEmail.from_dict(obj["email"]) if obj.get("email") is not None else None,
            "phone": UserServiceHumanPhone.from_dict(obj["phone"]) if obj.get("phone") is not None else None,
            "passwordChangeRequired": obj.get("passwordChangeRequired"),
            "passwordChanged": obj.get("passwordChanged"),
            "mfaInitSkipped": obj.get("mfaInitSkipped")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from zitadel_client.models.action_service_beta_condition import ActionServiceBetaCondition
from zitadel_client.models.action_service_beta_create_target_response import ActionServiceBetaCreateTargetResponse
from zitadel_client.models.action_service_beta_delete_target_response import ActionServiceBetaDeleteTargetResponse
from zitadel_client.models.action_service_beta_event_execution import ActionServiceBetaEventExecution
from zitadel_client.models.action_service_beta_execution import ActionServiceBetaExecution
from zitadel_client.models.action_service_beta_function_execution import ActionServiceBetaFunctionExecution
from zitadel_client.models.action_service_beta_get_target_response import ActionServiceBetaGetTargetResponse
from zitadel_client.models.action_service_beta_in_target_ids_filter import ActionServiceBetaInTargetIDsFilter
from zitadel_client.models.action_service_beta_list_execution_functions_response import ActionServiceBetaListExecutionFunctionsResponse
from zitadel_client.models.action_service_beta_list_execution_methods_response import ActionServiceBetaListExecutionMethodsResponse
from zitadel_client.models.action_service_beta_list_execution_services_response import ActionServiceBetaListExecutionServicesResponse
from zitadel_client.models.action_service_beta_list_executions_response import ActionServiceBetaListExecutionsResponse
from zitadel_client.models.action_service_beta_list_targets_response import ActionServiceBetaListTargetsResponse
from zitadel_client.models.action_service_beta_pagination_request import ActionServiceBetaPaginationRequest
from zitadel_client.models.action_service_beta_pagination_response import ActionServiceBetaPaginationResponse
from zitadel_client.models.action_service_beta_rest_call import ActionServiceBetaRESTCall
from zitadel_client.models.action_service_beta_rest_webhook import ActionServiceBetaRESTWebhook
from zitadel_client.models.action_service_beta_request_execution import ActionServiceBetaRequestExecution
from zitadel_client.models.action_service_beta_response_execution import ActionServiceBetaResponseExecution
from zitadel_client.models.action_service_beta_set_execution_response import ActionServiceBetaSetExecutionResponse
from zitadel_client.models.action_service_beta_target import ActionServiceBetaTarget
from zitadel_client.models.action_service_beta_target_field_name import ActionServiceBetaTargetFieldName
from zitadel_client.models.action_service_beta_target_name_filter import ActionServiceBetaTargetNameFilter
from zitadel_client.models.action_service_beta_target_search_filter import ActionServiceBetaTargetSearchFilter
from zitadel_client.models.action_service_beta_text_filter_method import ActionServiceBetaTextFilterMethod
from zitadel_client.models.action_service_beta_update_target_response import ActionServiceBetaUpdateTargetResponse
from zitadel_client.models.action_service_create_target_request import ActionServiceCreateTargetRequest
from zitadel_client.models.action_service_list_targets_request import ActionServiceListTargetsRequest
from zitadel_client.models.action_service_protobuf_any import ActionServiceProtobufAny
from zitadel_client.models.action_service_rpc_status import ActionServiceRpcStatus
from zitadel_client.models.action_service_set_execution_request import ActionServiceSetExecutionRequest
from zitadel_client.models.action_service_update_target_request import ActionServiceUpdateTargetRequest
from zitadel_client.models.feature_service_details import FeatureServiceDetails
from zitadel_client.models.feature_service_feature_flag import FeatureServiceFeatureFlag
from zitadel_client.models.feature_service_get_instance_features_response import FeatureServiceGetInstanceFeaturesResponse
from zitadel_client.models.feature_service_get_organization_features_response import FeatureServiceGetOrganizationFeaturesResponse
from zitadel_client.models.feature_service_get_system_features_response import FeatureServiceGetSystemFeaturesResponse
from zitadel_client.models.feature_service_get_user_features_response import FeatureServiceGetUserFeaturesResponse
from zitadel_client.models.feature_service_improved_performance import FeatureServiceImprovedPerformance
from zitadel_client.models.feature_service_improved_performance_feature_flag import FeatureServiceImprovedPerformanceFeatureFlag
from zitadel_client.models.feature_service_login_v2 import FeatureServiceLoginV2
from zitadel_client.models.feature_service_login_v2_feature_flag import FeatureServiceLoginV2FeatureFlag
from zitadel_client.models.feature_service_protobuf_any import FeatureServiceProtobufAny
from zitadel_client.models.feature_service_reset_instance_features_response import FeatureServiceResetInstanceFeaturesResponse
from zitadel_client.models.feature_service_reset_organization_features_response import FeatureServiceResetOrganizationFeaturesResponse
from zitadel_client.models.feature_service_reset_system_features_response import FeatureServiceResetSystemFeaturesResponse
from zitadel_client.models.feature_service_reset_user_features_response import FeatureServiceResetUserFeaturesResponse
from zitadel_client.models.feature_service_rpc_status import FeatureServiceRpcStatus
from zitadel_client.models.feature_service_set_instance_features_request import FeatureServiceSetInstanceFeaturesRequest
from zitadel_client.models.feature_service_set_instance_features_response import FeatureServiceSetInstanceFeaturesResponse
from zitadel_client.models.feature_service_set_organization_features_response import FeatureServiceSetOrganizationFeaturesResponse
from zitadel_client.models.feature_service_set_system_features_request import FeatureServiceSetSystemFeaturesRequest
from zitadel_client.models.feature_service_set_system_features_response import FeatureServiceSetSystemFeaturesResponse
from zitadel_client.models.feature_service_set_user_features_response import FeatureServiceSetUserFeaturesResponse
from zitadel_client.models.feature_service_source import FeatureServiceSource
from zitadel_client.models.identity_provider_service_apple_config import IdentityProviderServiceAppleConfig
from zitadel_client.models.identity_provider_service_auto_linking_option import IdentityProviderServiceAutoLinkingOption
from zitadel_client.models.identity_provider_service_azure_ad_config import IdentityProviderServiceAzureADConfig
from zitadel_client.models.identity_provider_service_azure_ad_tenant import IdentityProviderServiceAzureADTenant
from zitadel_client.models.identity_provider_service_azure_ad_tenant_type import IdentityProviderServiceAzureADTenantType
from zitadel_client.models.identity_provider_service_details import IdentityProviderServiceDetails
from zitadel_client.models.identity_provider_service_generic_oidc_config import IdentityProviderServiceGenericOIDCConfig
from zitadel_client.models.identity_provider_service_get_idpby_id_response import IdentityProviderServiceGetIDPByIDResponse
from zitadel_client.models.identity_provider_service_git_hub_config import IdentityProviderServiceGitHubConfig
from zitadel_client.models.identity_provider_service_git_hub_enterprise_server_config import IdentityProviderServiceGitHubEnterpriseServerConfig
from zitadel_client.models.identity_provider_service_git_lab_config import IdentityProviderServiceGitLabConfig
from zitadel_client.models.identity_provider_service_git_lab_self_hosted_config import IdentityProviderServiceGitLabSelfHostedConfig
from zitadel_client.models.identity_provider_service_google_config import IdentityProviderServiceGoogleConfig
from zitadel_client.models.identity_provider_service_idp import IdentityProviderServiceIDP
from zitadel_client.models.identity_provider_service_idp_config import IdentityProviderServiceIDPConfig
from zitadel_client.models.identity_provider_service_idp_state import IdentityProviderServiceIDPState
from zitadel_client.models.identity_provider_service_idp_type import IdentityProviderServiceIDPType
from zitadel_client.models.identity_provider_service_jwt_config import IdentityProviderServiceJWTConfig
from zitadel_client.models.identity_provider_service_ldap_attributes import IdentityProviderServiceLDAPAttributes
from zitadel_client.models.identity_provider_service_ldap_config import IdentityProviderServiceLDAPConfig
from zitadel_client.models.identity_provider_service_o_auth_config import IdentityProviderServiceOAuthConfig
from zitadel_client.models.identity_provider_service_options import IdentityProviderServiceOptions
from zitadel_client.models.identity_provider_service_protobuf_any import IdentityProviderServiceProtobufAny
from zitadel_client.models.identity_provider_service_rpc_status import IdentityProviderServiceRpcStatus
from zitadel_client.models.identity_provider_service_saml_binding import IdentityProviderServiceSAMLBinding
from zitadel_client.models.identity_provider_service_saml_config import IdentityProviderServiceSAMLConfig
from zitadel_client.models.identity_provider_service_saml_name_id_format import IdentityProviderServiceSAMLNameIDFormat
from zitadel_client.models.oidc_service_auth_request import OIDCServiceAuthRequest
from zitadel_client.models.oidc_service_authorization_error import OIDCServiceAuthorizationError
from zitadel_client.models.oidc_service_authorize_or_deny_device_authorization_request import OIDCServiceAuthorizeOrDenyDeviceAuthorizationRequest
from zitadel_client.models.oidc_service_create_callback_request import OIDCServiceCreateCallbackRequest
from zitadel_client.models.oidc_service_create_callback_response import OIDCServiceCreateCallbackResponse
from zitadel_client.models.oidc_service_details import OIDCServiceDetails
from zitadel_client.models.oidc_service_device_authorization_request import OIDCServiceDeviceAuthorizationRequest
from zitadel_client.models.oidc_service_error_reason import OIDCServiceErrorReason
from zitadel_client.models.oidc_service_get_auth_request_response import OIDCServiceGetAuthRequestResponse
from zitadel_client.models.oidc_service_get_device_authorization_request_response import OIDCServiceGetDeviceAuthorizationRequestResponse
from zitadel_client.models.oidc_service_prompt import OIDCServicePrompt
from zitadel_client.models.oidc_service_protobuf_any import OIDCServiceProtobufAny
from zitadel_client.models.oidc_service_rpc_status import OIDCServiceRpcStatus
from zitadel_client.models.oidc_service_session import OIDCServiceSession
from zitadel_client.models.organization_service_add_human_user_request import OrganizationServiceAddHumanUserRequest
from zitadel_client.models.organization_service_add_organization_request import OrganizationServiceAddOrganizationRequest
from zitadel_client.models.organization_service_add_organization_request_admin import OrganizationServiceAddOrganizationRequestAdmin
from zitadel_client.models.organization_service_add_organization_response import OrganizationServiceAddOrganizationResponse
from zitadel_client.models.organization_service_add_organization_response_created_admin import OrganizationServiceAddOrganizationResponseCreatedAdmin
from zitadel_client.models.organization_service_details import OrganizationServiceDetails
from zitadel_client.models.organization_service_gender import OrganizationServiceGender
from zitadel_client.models.organization_service_hashed_password import OrganizationServiceHashedPassword
from zitadel_client.models.organization_service_idp_link import OrganizationServiceIDPLink
from zitadel_client.models.organization_service_list_details import OrganizationServiceListDetails
from zitadel_client.models.organization_service_list_organizations_request import OrganizationServiceListOrganizationsRequest
from zitadel_client.models.organization_service_list_organizations_response import OrganizationServiceListOrganizationsResponse
from zitadel_client.models.organization_service_list_query import OrganizationServiceListQuery
from zitadel_client.models.organization_service_organization_domain_query import OrganizationServiceOrganizationDomainQuery
from zitadel_client.models.organization_service_organization_field_name import OrganizationServiceOrganizationFieldName
from zitadel_client.models.organization_service_organization_id_query import OrganizationServiceOrganizationIDQuery
from zitadel_client.models.organization_service_organization_name_query import OrganizationServiceOrganizationNameQuery
from zitadel_client.models.organization_service_organization_state import OrganizationServiceOrganizationState
from zitadel_client.models.organization_service_organization_state_query import OrganizationServiceOrganizationStateQuery
from zitadel_client.models.organization_service_password import OrganizationServicePassword
from zitadel_client.models.organization_service_protobuf_any import OrganizationServiceProtobufAny
from zitadel_client.models.organization_service_rpc_status import OrganizationServiceRpcStatus
from zitadel_client.models.organization_service_search_query import OrganizationServiceSearchQuery
from zitadel_client.models.organization_service_send_email_verification_code import OrganizationServiceSendEmailVerificationCode
from zitadel_client.models.organization_service_set_human_email import OrganizationServiceSetHumanEmail
from zitadel_client.models.organization_service_set_human_phone import OrganizationServiceSetHumanPhone
from zitadel_client.models.organization_service_set_human_profile import OrganizationServiceSetHumanProfile
from zitadel_client.models.organization_service_set_metadata_entry import OrganizationServiceSetMetadataEntry
from zitadel_client.models.organization_service_text_query_method import OrganizationServiceTextQueryMethod
from zitadel_client.models.saml_service_authorization_error import SAMLServiceAuthorizationError
from zitadel_client.models.saml_service_create_response_request import SAMLServiceCreateResponseRequest
from zitadel_client.models.saml_service_create_response_response import SAMLServiceCreateResponseResponse
from zitadel_client.models.saml_service_details import SAMLServiceDetails
from zitadel_client.models.saml_service_error_reason import SAMLServiceErrorReason
from zitadel_client.models.saml_service_get_saml_request_response import SAMLServiceGetSAMLRequestResponse
from zitadel_client.models.saml_service_post_response import SAMLServicePostResponse
from zitadel_client.models.saml_service_protobuf_any import SAMLServiceProtobufAny
from zitadel_client.models.saml_service_rpc_status import SAMLServiceRpcStatus
from zitadel_client.models.saml_service_saml_request import SAMLServiceSAMLRequest
from zitadel_client.models.saml_service_session import SAMLServiceSession
from zitadel_client.models.session_service_challenges import SessionServiceChallenges
from zitadel_client.models.session_service_challenges_web_auth_n import SessionServiceChallengesWebAuthN
from zitadel_client.models.session_service_check_idp_intent import SessionServiceCheckIDPIntent
from zitadel_client.models.session_service_check_otp import SessionServiceCheckOTP
from zitadel_client.models.session_service_check_password import SessionServiceCheckPassword
from zitadel_client.models.session_service_check_totp import SessionServiceCheckTOTP
from zitadel_client.models.session_service_check_user import SessionServiceCheckUser
from zitadel_client.models.session_service_check_web_auth_n import SessionServiceCheckWebAuthN
from zitadel_client.models.session_service_checks import SessionServiceChecks
from zitadel_client.models.session_service_create_session_request import SessionServiceCreateSessionRequest
from zitadel_client.models.session_service_create_session_response import SessionServiceCreateSessionResponse
from zitadel_client.models.session_service_creation_date_query import SessionServiceCreationDateQuery
from zitadel_client.models.session_service_creator_query import SessionServiceCreatorQuery
from zitadel_client.models.session_service_delete_session_request import SessionServiceDeleteSessionRequest
from zitadel_client.models.session_service_delete_session_response import SessionServiceDeleteSessionResponse
from zitadel_client.models.session_service_details import SessionServiceDetails
from zitadel_client.models.session_service_factors import SessionServiceFactors
from zitadel_client.models.session_service_get_session_response import SessionServiceGetSessionResponse
from zitadel_client.models.session_service_ids_query import SessionServiceIDsQuery
from zitadel_client.models.session_service_intent_factor import SessionServiceIntentFactor
from zitadel_client.models.session_service_list_details import SessionServiceListDetails
from zitadel_client.models.session_service_list_query import SessionServiceListQuery
from zitadel_client.models.session_service_list_sessions_request import SessionServiceListSessionsRequest
from zitadel_client.models.session_service_list_sessions_response import SessionServiceListSessionsResponse
from zitadel_client.models.session_service_otp_email_send_code import SessionServiceOTPEmailSendCode
from zitadel_client.models.session_service_otp_factor import SessionServiceOTPFactor
from zitadel_client.models.session_service_password_factor import SessionServicePasswordFactor
from zitadel_client.models.session_service_protobuf_any import SessionServiceProtobufAny
from zitadel_client.models.session_service_request_challenges import SessionServiceRequestChallenges
from zitadel_client.models.session_service_request_challenges_otp_email import SessionServiceRequestChallengesOTPEmail
from zitadel_client.models.session_service_request_challenges_otpsms import SessionServiceRequestChallengesOTPSMS
from zitadel_client.models.session_service_request_challenges_web_auth_n import SessionServiceRequestChallengesWebAuthN
from zitadel_client.models.session_service_rpc_status import SessionServiceRpcStatus
from zitadel_client.models.session_service_search_query import SessionServiceSearchQuery
from zitadel_client.models.session_service_session import SessionServiceSession
from zitadel_client.models.session_service_session_field_name import SessionServiceSessionFieldName
from zitadel_client.models.session_service_set_session_request import SessionServiceSetSessionRequest
from zitadel_client.models.session_service_set_session_response import SessionServiceSetSessionResponse
from zitadel_client.models.session_service_totp_factor import SessionServiceTOTPFactor
from zitadel_client.models.session_service_timestamp_query_method import SessionServiceTimestampQueryMethod
from zitadel_client.models.session_service_user_agent import SessionServiceUserAgent
from zitadel_client.models.session_service_user_agent_header_values import SessionServiceUserAgentHeaderValues
from zitadel_client.models.session_service_user_agent_query import SessionServiceUserAgentQuery
from zitadel_client.models.session_service_user_factor import SessionServiceUserFactor
from zitadel_client.models.session_service_user_id_query import SessionServiceUserIDQuery
from zitadel_client.models.session_service_user_verification_requirement import SessionServiceUserVerificationRequirement
from zitadel_client.models.session_service_web_auth_n_factor import SessionServiceWebAuthNFactor
from zitadel_client.models.settings_service_auto_linking_option import SettingsServiceAutoLinkingOption
from zitadel_client.models.settings_service_branding_settings import SettingsServiceBrandingSettings
from zitadel_client.models.settings_service_details import SettingsServiceDetails
from zitadel_client.models.settings_service_domain_settings import SettingsServiceDomainSettings
from zitadel_client.models.settings_service_embedded_iframe_settings import SettingsServiceEmbeddedIframeSettings
from zitadel_client.models.settings_service_get_active_identity_providers_response import SettingsServiceGetActiveIdentityProvidersResponse
from zitadel_client.models.settings_service_get_branding_settings_response import SettingsServiceGetBrandingSettingsResponse
from zitadel_client.models.settings_service_get_domain_settings_response import SettingsServiceGetDomainSettingsResponse
from zitadel_client.models.settings_service_get_general_settings_response import SettingsServiceGetGeneralSettingsResponse
from zitadel_client.models.settings_service_get_legal_and_support_settings_response import SettingsServiceGetLegalAndSupportSettingsResponse
from zitadel_client.models.settings_service_get_lockout_settings_response import SettingsServiceGetLockoutSettingsResponse
from zitadel_client.models.settings_service_get_login_settings_response import SettingsServiceGetLoginSettingsResponse
from zitadel_client.models.settings_service_get_password_complexity_settings_response import SettingsServiceGetPasswordComplexitySettingsResponse
from zitadel_client.models.settings_service_get_password_expiry_settings_response import SettingsServiceGetPasswordExpirySettingsResponse
from zitadel_client.models.settings_service_get_security_settings_response import SettingsServiceGetSecuritySettingsResponse
from zitadel_client.models.settings_service_identity_provider import SettingsServiceIdentityProvider
from zitadel_client.models.settings_service_identity_provider_type import SettingsServiceIdentityProviderType
from zitadel_client.models.settings_service_legal_and_support_settings import SettingsServiceLegalAndSupportSettings
from zitadel_client.models.settings_service_list_details import SettingsServiceListDetails
from zitadel_client.models.settings_service_lockout_settings import SettingsServiceLockoutSettings
from zitadel_client.models.settings_service_login_settings import SettingsServiceLoginSettings
from zitadel_client.models.settings_service_multi_factor_type import SettingsServiceMultiFactorType
from zitadel_client.models.settings_service_options import SettingsServiceOptions
from zitadel_client.models.settings_service_passkeys_type import SettingsServicePasskeysType
from zitadel_client.models.settings_service_password_complexity_settings import SettingsServicePasswordComplexitySettings
from zitadel_client.models.settings_service_password_expiry_settings import SettingsServicePasswordExpirySettings
from zitadel_client.models.settings_service_protobuf_any import SettingsServiceProtobufAny
from zitadel_client.models.settings_service_resource_owner_type import SettingsServiceResourceOwnerType
from zitadel_client.models.settings_service_rpc_status import SettingsServiceRpcStatus
from zitadel_client.models.settings_service_second_factor_type import SettingsServiceSecondFactorType
from zitadel_client.models.settings_service_security_settings import SettingsServiceSecuritySettings
from zitadel_client.models.settings_service_set_security_settings_request import SettingsServiceSetSecuritySettingsRequest
from zitadel_client.models.settings_service_set_security_settings_response import SettingsServiceSetSecuritySettingsResponse
from zitadel_client.models.settings_service_theme import SettingsServiceTheme
from zitadel_client.models.settings_service_theme_mode import SettingsServiceThemeMode
from zitadel_client.models.user_service_access_token_type import UserServiceAccessTokenType
from zitadel_client.models.user_service_add_human_user_request import UserServiceAddHumanUserRequest
from zitadel_client.models.user_service_add_human_user_response import UserServiceAddHumanUserResponse
from zitadel_client.models.user_service_add_idp_link_request import UserServiceAddIDPLinkRequest
from zitadel_client.models.user_service_add_idp_link_response import UserServiceAddIDPLinkResponse
from zitadel_client.models.user_service_add_otp_email_response import UserServiceAddOTPEmailResponse
from zitadel_client.models.user_service_add_otpsms_response import UserServiceAddOTPSMSResponse
from zitadel_client.models.user_service_and_query import UserServiceAndQuery
from zitadel_client.models.user_service_auth_factor import UserServiceAuthFactor
from zitadel_client.models.user_service_auth_factor_state import UserServiceAuthFactorState
from zitadel_client.models.user_service_auth_factor_u2_f import UserServiceAuthFactorU2F
from zitadel_client.models.user_service_authentication_method_type import UserServiceAuthenticationMethodType
from zitadel_client.models.user_service_create_invite_code_request import UserServiceCreateInviteCodeRequest
from zitadel_client.models.user_service_create_invite_code_response import UserServiceCreateInviteCodeResponse
from zitadel_client.models.user_service_create_passkey_registration_link_request import UserServiceCreatePasskeyRegistrationLinkRequest
from zitadel_client.models.user_service_create_passkey_registration_link_response import UserServiceCreatePasskeyRegistrationLinkResponse
from zitadel_client.models.user_service_deactivate_user_response import UserServiceDeactivateUserResponse
from zitadel_client.models.user_service_delete_user_response import UserServiceDeleteUserResponse
from zitadel_client.models.user_service_details import UserServiceDetails
from zitadel_client.models.user_service_display_name_query import UserServiceDisplayNameQuery
from zitadel_client.models.user_service_email_query import UserServiceEmailQuery
from zitadel_client.models.user_service_first_name_query import UserServiceFirstNameQuery
from zitadel_client.models.user_service_gender import UserServiceGender
from zitadel_client.models.user_service_get_user_by_id_response import UserServiceGetUserByIDResponse
from zitadel_client.models.user_service_hashed_password import UserServiceHashedPassword
from zitadel_client.models.user_service_human_email import UserServiceHumanEmail
from zitadel_client.models.user_service_human_mfa_init_skipped_response import UserServiceHumanMFAInitSkippedResponse
from zitadel_client.models.user_service_human_phone import UserServiceHumanPhone
from zitadel_client.models.user_service_human_profile import UserServiceHumanProfile
from zitadel_client.models.user_service_human_user import UserServiceHumanUser
from zitadel_client.models.user_service_idp_information import UserServiceIDPInformation
from zitadel_client.models.user_service_idp_intent import UserServiceIDPIntent
from zitadel_client.models.user_service_idpldap_access_information import UserServiceIDPLDAPAccessInformation
from zitadel_client.models.user_service_idp_link import UserServiceIDPLink
from zitadel_client.models.user_service_idpo_auth_access_information import UserServiceIDPOAuthAccessInformation
from zitadel_client.models.user_service_idpsaml_access_information import UserServiceIDPSAMLAccessInformation
from zitadel_client.models.user_service_in_user_emails_query import UserServiceInUserEmailsQuery
from zitadel_client.models.user_service_in_user_id_query import UserServiceInUserIDQuery
from zitadel_client.models.user_service_ldap_credentials import UserServiceLDAPCredentials
from zitadel_client.models.user_service_last_name_query import UserServiceLastNameQuery
from zitadel_client.models.user_service_list_authentication_factors_response import UserServiceListAuthenticationFactorsResponse
from zitadel_client.models.user_service_list_authentication_method_types_response import UserServiceListAuthenticationMethodTypesResponse
from zitadel_client.models.user_service_list_details import UserServiceListDetails
from zitadel_client.models.user_service_list_idp_links_request import UserServiceListIDPLinksRequest
from zitadel_client.models.user_service_list_idp_links_response import UserServiceListIDPLinksResponse
from zitadel_client.models.user_service_list_passkeys_response import UserServiceListPasskeysResponse
from zitadel_client.models.user_service_list_query import UserServiceListQuery
from zitadel_client.models.user_service_list_users_request import UserServiceListUsersRequest
from zitadel_client.models.user_service_list_users_response import UserServiceListUsersResponse
from zitadel_client.models.user_service_lock_user_response import UserServiceLockUserResponse
from zitadel_client.models.user_service_login_name_query import UserServiceLoginNameQuery
from zitadel_client.models.user_service_machine_user import UserServiceMachineUser
from zitadel_client.models.user_service_nick_name_query import UserServiceNickNameQuery
from zitadel_client.models.user_service_not_query import UserServiceNotQuery
from zitadel_client.models.user_service_notification_type import UserServiceNotificationType
from zitadel_client.models.user_service_or_query import UserServiceOrQuery
from zitadel_client.models.user_service_organization import UserServiceOrganization
from zitadel_client.models.user_service_organization_id_query import UserServiceOrganizationIdQuery
from zitadel_client.models.user_service_passkey import UserServicePasskey
from zitadel_client.models.user_service_passkey_authenticator import UserServicePasskeyAuthenticator
from zitadel_client.models.user_service_passkey_registration_code import UserServicePasskeyRegistrationCode
from zitadel_client.models.user_service_password import UserServicePassword
from zitadel_client.models.user_service_password_reset_request import UserServicePasswordResetRequest
from zitadel_client.models.user_service_password_reset_response import UserServicePasswordResetResponse
from zitadel_client.models.user_service_phone_query import UserServicePhoneQuery
from zitadel_client.models.user_service_protobuf_any import UserServiceProtobufAny
from zitadel_client.models.user_service_reactivate_user_response import UserServiceReactivateUserResponse
from zitadel_client.models.user_service_redirect_urls import UserServiceRedirectURLs
from zitadel_client.models.user_service_register_passkey_request import UserServiceRegisterPasskeyRequest
from zitadel_client.models.user_service_register_passkey_response import UserServiceRegisterPasskeyResponse
from zitadel_client.models.user_service_register_totp_response import UserServiceRegisterTOTPResponse
from zitadel_client.models.user_service_register_u2_f_request import UserServiceRegisterU2FRequest
from zitadel_client.models.user_service_register_u2_f_response import UserServiceRegisterU2FResponse
from zitadel_client.models.user_service_remove_idp_link_response import UserServiceRemoveIDPLinkResponse
from zitadel_client.models.user_service_remove_otp_email_response import UserServiceRemoveOTPEmailResponse
from zitadel_client.models.user_service_remove_otpsms_response import UserServiceRemoveOTPSMSResponse
from zitadel_client.models.user_service_remove_passkey_response import UserServiceRemovePasskeyResponse
from zitadel_client.models.user_service_remove_phone_response import UserServiceRemovePhoneResponse
from zitadel_client.models.user_service_remove_totp_response import UserServiceRemoveTOTPResponse
from zitadel_client.models.user_service_remove_u2_f_response import UserServiceRemoveU2FResponse
from zitadel_client.models.user_service_resend_email_code_request import UserServiceResendEmailCodeRequest
from zitadel_client.models.user_service_resend_email_code_response import UserServiceResendEmailCodeResponse
from zitadel_client.models.user_service_resend_invite_code_response import UserServiceResendInviteCodeResponse
from zitadel_client.models.user_service_resend_phone_code_request import UserServiceResendPhoneCodeRequest
from zitadel_client.models.user_service_resend_phone_code_response import UserServiceResendPhoneCodeResponse
from zitadel_client.models.user_service_retrieve_identity_provider_intent_request import UserServiceRetrieveIdentityProviderIntentRequest
from zitadel_client.models.user_service_retrieve_identity_provider_intent_response import UserServiceRetrieveIdentityProviderIntentResponse
from zitadel_client.models.user_service_rpc_status import UserServiceRpcStatus
from zitadel_client.models.user_service_search_query import UserServiceSearchQuery
from zitadel_client.models.user_service_send_email_code_request import UserServiceSendEmailCodeRequest
from zitadel_client.models.user_service_send_email_code_response import UserServiceSendEmailCodeResponse
from zitadel_client.models.user_service_send_email_verification_code import UserServiceSendEmailVerificationCode
from zitadel_client.models.user_service_send_invite_code import UserServiceSendInviteCode
from zitadel_client.models.user_service_send_passkey_registration_link import UserServiceSendPasskeyRegistrationLink
from zitadel_client.models.user_service_send_password_reset_link import UserServiceSendPasswordResetLink
from zitadel_client.models.user_service_set_email_request import UserServiceSetEmailRequest
from zitadel_client.models.user_service_set_email_response import UserServiceSetEmailResponse
from zitadel_client.models.user_service_set_human_email import UserServiceSetHumanEmail
from zitadel_client.models.user_service_set_human_phone import UserServiceSetHumanPhone
from zitadel_client.models.user_service_set_human_profile import UserServiceSetHumanProfile
from zitadel_client.models.user_service_set_metadata_entry import UserServiceSetMetadataEntry
from zitadel_client.models.user_service_set_password import UserServiceSetPassword
from zitadel_client.models.user_service_set_password_request import UserServiceSetPasswordRequest
from zitadel_client.models.user_service_set_password_response import UserServiceSetPasswordResponse
from zitadel_client.models.user_service_set_phone_request import UserServiceSetPhoneRequest
from zitadel_client.models.user_service_set_phone_response import UserServiceSetPhoneResponse
from zitadel_client.models.user_service_start_identity_provider_intent_request import UserServiceStartIdentityProviderIntentRequest
from zitadel_client.models.user_service_start_identity_provider_intent_response import UserServiceStartIdentityProviderIntentResponse
from zitadel_client.models.user_service_state_query import UserServiceStateQuery
from zitadel_client.models.user_service_text_query_method import UserServiceTextQueryMethod
from zitadel_client.models.user_service_type import UserServiceType
from zitadel_client.models.user_service_type_query import UserServiceTypeQuery
from zitadel_client.models.user_service_unlock_user_response import UserServiceUnlockUserResponse
from zitadel_client.models.user_service_update_human_user_request import UserServiceUpdateHumanUserRequest
from zitadel_client.models.user_service_update_human_user_response import UserServiceUpdateHumanUserResponse
from zitadel_client.models.user_service_user import UserServiceUser
from zitadel_client.models.user_service_user_field_name import UserServiceUserFieldName
from zitadel_client.models.user_service_user_name_query import UserServiceUserNameQuery
from zitadel_client.models.user_service_user_state import UserServiceUserState
from zitadel_client.models.user_service_verify_email_request import UserServiceVerifyEmailRequest
from zitadel_client.models.user_service_verify_email_response import UserServiceVerifyEmailResponse
from zitadel_client.models.user_service_verify_invite_code_request import UserServiceVerifyInviteCodeRequest
from zitadel_client.models.user_service_verify_invite_code_response import UserServiceVerifyInviteCodeResponse
from zitadel_client.models.user_service_verify_passkey_registration_request import UserServiceVerifyPasskeyRegistrationRequest
from zitadel_client.models.user_service_verify_passkey_registration_response import UserServiceVerifyPasskeyRegistrationResponse
from zitadel_client.models.user_service_verify_phone_request import UserServiceVerifyPhoneRequest
from zitadel_client.models.user_service_verify_phone_response import UserServiceVerifyPhoneResponse
from zitadel_client.models.user_service_verify_totp_registration_request import UserServiceVerifyTOTPRegistrationRequest
from zitadel_client.models.user_service_verify_totp_registration_response import UserServiceVerifyTOTPRegistrationResponse
from zitadel_client.models.user_service_verify_u2_f_registration_request import UserServiceVerifyU2FRegistrationRequest
from zitadel_client.models.user_service_verify_u2_f_registration_response import UserServiceVerifyU2FRegistrationResponse
from zitadel_client.models.web_key_service_beta_activate_web_key_response import WebKeyServiceBetaActivateWebKeyResponse
from zitadel_client.models.web_key_service_beta_create_web_key_response import WebKeyServiceBetaCreateWebKeyResponse
from zitadel_client.models.web_key_service_beta_delete_web_key_response import WebKeyServiceBetaDeleteWebKeyResponse
from zitadel_client.models.web_key_service_beta_ecdsa import WebKeyServiceBetaECDSA
from zitadel_client.models.web_key_service_beta_ecdsa_curve import WebKeyServiceBetaECDSACurve
from zitadel_client.models.web_key_service_beta_list_web_keys_response import WebKeyServiceBetaListWebKeysResponse
from zitadel_client.models.web_key_service_beta_rsa import WebKeyServiceBetaRSA
from zitadel_client.models.web_key_service_beta_rsa_bits import WebKeyServiceBetaRSABits
from zitadel_client.models.web_key_service_beta_rsa_hasher import WebKeyServiceBetaRSAHasher
from zitadel_client.models.web_key_service_beta_state import WebKeyServiceBetaState
from zitadel_client.models.web_key_service_beta_web_key import WebKeyServiceBetaWebKey
from zitadel_client.models.web_key_service_create_web_key_request import WebKeyServiceCreateWebKeyRequest
from zitadel_client.models.web_key_service_protobuf_any import WebKeyServiceProtobufAny
from zitadel_client.models.web_key_service_rpc_status import WebKeyServiceRpcStatus
from zitadel_client.models.zitadelobjectv2_organization import Zitadelobjectv2Organization
from zitadel_client.models.zitadelorgv2_organization import Zitadelorgv2Organization



# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from zitadel_client.models.feature_service_improved_performance import FeatureServiceImprovedPerformance
from zitadel_client.models.feature_service_login_v2 import FeatureServiceLoginV2
from typing import Optional, Set
from typing_extensions import Self

class FeatureServiceSetSystemFeaturesRequest(BaseModel):
    """
    FeatureServiceSetSystemFeaturesRequest
    """ # noqa: E501
    login_default_org: Optional[StrictBool] = Field(default=None, description="The login UI will use the settings of the default org (and not from the instance) if no organization context is set", alias="loginDefaultOrg")
    oidc_trigger_introspection_projections: Optional[StrictBool] = Field(default=None, description="Enable projection triggers during an introspection request. This can act as workaround if there are noticeable consistency issues in the introspection response but can have an impact on performance. We are planning to remove triggers for introspection requests in the future. Please raise an issue if you needed to enable this feature.", alias="oidcTriggerIntrospectionProjections")
    oidc_legacy_introspection: Optional[StrictBool] = Field(default=None, description="We have recently refactored the introspection endpoint for performance reasons. This feature can be used to rollback to the legacy implementation if unexpected bugs arise. Please raise an issue if you needed to enable this feature.", alias="oidcLegacyIntrospection")
    user_schema: Optional[StrictBool] = Field(default=None, description="User Schemas allow to manage data schemas of user. If the flag is enabled, you'll be able to use the new API and its features. Note that it is still in an early stage.", alias="userSchema")
    oidc_token_exchange: Optional[StrictBool] = Field(default=None, description="Enable the experimental `urn:ietf:params:oauth:grant-type:token-exchange` grant type for the OIDC token endpoint. Token exchange can be used to request tokens with a lesser scope or impersonate other users. See the security policy to allow impersonation on an instance.", alias="oidcTokenExchange")
    improved_performance: Optional[List[FeatureServiceImprovedPerformance]] = Field(default=None, description="Improves performance of specified execution paths.", alias="improvedPerformance")
    oidc_single_v1_session_termination: Optional[StrictBool] = Field(default=None, description="If the flag is enabled, you'll be able to terminate a single session from the login UI by providing an id_token with a `sid` claim as id_token_hint on the end_session endpoint. Note that currently all sessions from the same user agent (browser) are terminated in the login UI. Sessions managed through the Session API already allow the termination of single sessions.", alias="oidcSingleV1SessionTermination")
    disable_user_token_event: Optional[StrictBool] = Field(default=None, description="Do not push user token meta-event user.token.v2.added to improve performance on many concurrent single (machine-)user logins", alias="disableUserTokenEvent")
    enable_back_channel_logout: Optional[StrictBool] = Field(default=None, description="If the flag is enabled, you'll be able to use the OIDC Back-Channel Logout to be notified in your application about terminated user sessions.", alias="enableBackChannelLogout")
    login_v2: Optional[FeatureServiceLoginV2] = Field(default=None, alias="loginV2")
    permission_check_v2: Optional[StrictBool] = Field(default=None, description="Enable a newer, more performant, permission check used for v2 and v3 resource based APIs.", alias="permissionCheckV2")

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FeatureServiceSetSystemFeaturesRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of login_v2
        if self.login_v2:
            _dict['loginV2'] = self.login_v2.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FeatureServiceSetSystemFeaturesRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "loginDefaultOrg": obj.get("loginDefaultOrg"),
            "oidcTriggerIntrospectionProjections": obj.get("oidcTriggerIntrospectionProjections"),
            "oidcLegacyIntrospection": obj.get("oidcLegacyIntrospection"),
            "userSchema": obj.get("userSchema"),
            "oidcTokenExchange": obj.get("oidcTokenExchange"),
            "improvedPerformance": obj.get("improvedPerformance"),
            "oidcSingleV1SessionTermination": obj.get("oidcSingleV1SessionTermination"),
            "disableUserTokenEvent": obj.get("disableUserTokenEvent"),
            "enableBackChannelLogout": obj.get("enableBackChannelLogout"),
            "loginV2": FeatureServiceLoginV2.from_dict(obj["loginV2"]) if obj.get("loginV2") is not None else None,
            "permissionCheckV2": obj.get("permissionCheckV2")
        })
        return _obj





import json
import urllib
import urllib.error
import urllib.request
from urllib.parse import urljoin


class OpenId:
    """
    OpenId retrieves OpenID Connect configuration from a given host.

    It builds the well-known configuration URL from the provided hostname,
    fetches the configuration, and extracts the token endpoint.
    """

    host_endpoint: str
    token_endpoint: str

    def __init__(self, hostname: str):
        if not (hostname.startswith("http://") or hostname.startswith("https://")):
            hostname = "https://" + hostname

        self.host_endpoint = hostname
        well_known_url = self.build_well_known_url(hostname)

        try:
            if not well_known_url.lower().startswith(("http://", "https://")):
                raise ValueError("Invalid URL scheme. Only 'http' and 'https' are allowed.")

            with urllib.request.urlopen(well_known_url) as response:  # noqa S310
                if response.status != 200:
                    raise Exception(f"Failed to fetch OpenID configuration: HTTP {response.status}")
                config = json.loads(response.read().decode("utf-8"))
        except urllib.error.URLError as e:
            raise Exception(f"URL error occurred: {e}") from e
        except json.JSONDecodeError as e:
            raise Exception("Failed to decode JSON response") from e

        token_endpoint = config.get("token_endpoint")
        if not token_endpoint:
            raise Exception("token_endpoint not found in OpenID configuration")

        self.token_endpoint = token_endpoint

    @staticmethod
    def build_well_known_url(hostname: str) -> str:
        """
        Builds the well-known OpenID configuration URL for the given hostname.
        """
        return urljoin(hostname, "/.well-known/openid-configuration")

    def get_host_endpoint(self) -> str:
        """
        Returns the host endpoint URL.
        """
        return self.host_endpoint

    def get_token_endpoint(self) -> str:
        """
        Returns the token endpoint URL extracted from the OpenID configuration.
        """
        return self.token_endpoint



# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class WebKeyServiceBetaState(str, Enum):
    """
     - STATE_INITIAL: A newly created key is in the initial state and published to the public key endpoint.  - STATE_ACTIVE: The active key is used to sign tokens. Only one key can be active at a time.  - STATE_INACTIVE: The inactive key is not used to sign tokens anymore, but still published to the public key endpoint.  - STATE_REMOVED: The removed key is not used to sign tokens anymore and not published to the public key endpoint.
    """

    """
    allowed enum values
    """
    STATE_UNSPECIFIED = 'STATE_UNSPECIFIED'
    STATE_INITIAL = 'STATE_INITIAL'
    STATE_ACTIVE = 'STATE_ACTIVE'
    STATE_INACTIVE = 'STATE_INACTIVE'
    STATE_REMOVED = 'STATE_REMOVED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of WebKeyServiceBetaState from a JSON string"""
        return cls(json.loads(json_str))





from typing import Any, Dict, Optional


class ZitadelError(Exception):
    """Base exception for all Zitadel API errors."""


class ApiError(ZitadelError):
    """
    Represents an HTTP error from the Zitadel API.

    Attributes:
      code             int HTTP status code
      response_headers Dict[str, str] HTTP response headers
      response_body Any HTTP response body
    """

    def __init__(
        self,
        code: int,
        response_headers: Dict[str, str],
        response_body: Optional[Any],
    ) -> None:
        super().__init__(f"Error {code}")
        self.code = code
        self.response_headers = response_headers
        self.response_body = response_body



# flake8: noqa

# import apis into api package
from zitadel_client.api.action_service_api import ActionServiceApi
from zitadel_client.api.feature_service_api import FeatureServiceApi
from zitadel_client.api.identity_provider_service_api import IdentityProviderServiceApi
from zitadel_client.api.oidc_service_api import OIDCServiceApi
from zitadel_client.api.organization_service_api import OrganizationServiceApi
from zitadel_client.api.saml_service_api import SAMLServiceApi
from zitadel_client.api.session_service_api import SessionServiceApi
from zitadel_client.api.settings_service_api import SettingsServiceApi
from zitadel_client.api.user_service_api import UserServiceApi
from zitadel_client.api.web_key_service_api import WebKeyServiceApi




# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class IdentityProviderServiceAutoLinkingOption(str, Enum):
    """
     - AUTO_LINKING_OPTION_UNSPECIFIED: AUTO_LINKING_OPTION_UNSPECIFIED disables the auto linking prompt.  - AUTO_LINKING_OPTION_USERNAME: AUTO_LINKING_OPTION_USERNAME will use the username of the external user to check for a corresponding ZITADEL user.  - AUTO_LINKING_OPTION_EMAIL: AUTO_LINKING_OPTION_EMAIL  will use the email of the external user to check for a corresponding ZITADEL user with the same verified email Note that in case multiple users match, no prompt will be shown.
    """

    """
    allowed enum values
    """
    AUTO_LINKING_OPTION_UNSPECIFIED = 'AUTO_LINKING_OPTION_UNSPECIFIED'
    AUTO_LINKING_OPTION_USERNAME = 'AUTO_LINKING_OPTION_USERNAME'
    AUTO_LINKING_OPTION_EMAIL = 'AUTO_LINKING_OPTION_EMAIL'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of IdentityProviderServiceAutoLinkingOption from a JSON string"""
        return cls(json.loads(json_str))


